# How long to wait for shutdown
DT_SHUTDOWN_WAIT=60

get_kernel_bitness() {
    case `uname` in
	'AIX')
	    getconf KERNEL_BITMODE
	    ;;
	'SunOS')
	    isainfo -b
	    ;;
	'HP-UX')
	    getconf KERNEL_BITS
	    ;;
	'OS/390')
	    64
	    ;;
	*)
	    getconf LONG_BIT
	    ;;
	esac;
}

calculate_secret_sauce() {
    echo "$@" | cksum | awk '{{print $1}}'
}

# $1 = pid, $2 = binary, $3 = name, $4 = hash, $5 = guess
_status() {
	pid=$1; shift;
	binary=$1; shift;
	name=$1; shift;
	hash=$1; shift;
	guess=$1; shift;
    if [ -n "$pid" ]; then
      echo "Dynatrace $name daemon is running:"
      ps -ef | grep $binary | grep $hash
      return 0
    elif [ -n "$guess" ]; then
      echo "Dynatrace $name daemon might be running but probably hasn't been started via the init.d script."
      echo "You won't be able to stop it with this script, please use manual signals to stop it:"
      ps -fp $guess
      return 4
    else
      echo "Dynatrace $name daemon not running."
      return 3
    fi
}

# $1 = pid, $2 = binary, $3 = name, $4 = hash, $5 = optional arguments
_start() {
	pid=$1; shift;
	binary=$1; shift;
	name=$1; shift;
	hash=$1; shift;
	if [ -z $pid ]; then
		echo "${DT_HOME}"/$binary -bg $hash "$@"
		if [ -z "${DT_RUNASUSER}" ]; then
			"${DT_HOME}"/$binary -bg $hash "$@"
		else
			su -c "${DT_HOME}/$binary -bg $hash $@" "${DT_RUNASUSER}"
		fi
	else
		echo "Dynatrace $name daemon is already running!"
	fi
}

# $1 = pid, $2 = name
_stop() {
	pid=$1; shift;
	name=$1; shift;
	if [ -n "$pid" ]; then
		echo "Terminating Dynatrace $name process $pid"
		kill -15 $pid
		COUNT=0;
		while [ `ps -A -o pid | grep -c $pid` -gt 0 ] && [ "${COUNT}" -lt "${DT_SHUTDOWN_WAIT}" ]
		do
			echo "Waiting for Dynatrace $name ($pid) to finish shutdown";
			sleep 1
			COUNT=`expr ${COUNT} + 1`
		done

		if [ "${COUNT}" -gt "${DT_SHUTDOWN_WAIT}" ]; then
			echo "Killing Dynatrace $name ($pid) because the shutdown lasted longer than ${DT_SHUTDOWN_WAIT} seconds"
			kill -9 $pid
		fi
	fi
}
